@@ -1,5 +1,4 @@
-/* $Id: adaproject_part.h,v 1.5 2004/02/15 00:41:09 geiseri Exp $
- * Copyright (C) 2003 Oliver Kellogg
+/* Copyright (C) 2003 Oliver Kellogg
  * okellogg@users.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or modify
@@ -12,13 +11,13 @@
 
 #include <qguardedptr.h>
 
-#include "kdevproject.h"
+#include "kdevbuildtool.h"
 
 class AdaProjectWidget;
 class KDialogBase;
 class KDevCompilerOptions;
 
-class AdaProjectPart : public KDevProject
+class AdaProjectPart : public KDevBuildTool
 {
     Q_OBJECT
 public:
@@ -30,7 +29,7 @@ public:
 
     /**Returns the name of the main source file without extension.
        We assume that all Ada compilers call the binary that way.  */
-    virtual QString mainProgram(bool relative = false) const;
+    virtual QString mainProgram() const;
     /**Main source file (like src/main.adb)*/
     virtual QString mainSource() const;
     virtual void setMainSource(QString fullPath);
@@ -41,6 +40,7 @@ public:
     /**The location of the main source file*/
     virtual QString buildDirectory() const;
     virtual QString runDirectory() const;
+    virtual QString debugArguments() const;
     virtual QString runArguments() const;
     virtual DomUtil::PairList runEnvironmentVars() const;
 
